#ifndef __PHAT_H__
#define __PHAT_H__

#include <phat/phatvfanslider.h>
#include <phat/phathfanslider.h>
#include <phat/phatfanslider.h>
#include <phat/phatsliderbutton.h>
#include <phat/phatkeyboard.h>
#include <phat/phatvkeyboard.h>
#include <phat/phathkeyboard.h>

#endif /* __PHAT_H__ */
